<!DOCTYPE html>
<html lang="en">
    <head>
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css">
        <script src="https://code.jquery.com/jquery-2.1.4.min.js"></script>
        <script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/js/bootstrap.min.js"></script>
        <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/font-awesome/4.6.3/css/font-awesome.min.css">
        <style>
        @media (min-width: 768px) {
        .modal-dialog {
            width: auto;
            margin: 30px 30px;
        }
        }
        </style>
    </head>
    <body>
        <div class="container">
            {% block content %}
            {% endblock %}{# content #}
        </div><!-- .container -->
    </body>
</html>
